PtrBuffer

Struct PtrBuffer 

pub struct PtrBuffer { /* private fields */ }
A Buffer object backed by a pointer/size pair. Use this buffer type when accessing unowned memory or arbitrary allocated memory.

Implementations

Source

impl PtrBuffer

pub fn new(pointer: *const u8, size: usize) -> Self

Create a new buffer object with a given pointer and size. Just make sure the pointer outlives the object and not the other way around.

pub fn set_pointer(&mut self, pointer: *const u8)

Set the new pointer of this buffer.

pub fn set_size(&mut self, size: usize)

Set the new size of this buffer.

pub fn sub_buffer(&self, offset: usize, size: usize) -> Result<Self, Error>

Create a new PtrBuffer object within the bounds of the current buffer.

pub fn split_at(&self, mid: usize) -> Result<(Self, Self), Error>

Split this buffer into two separate buffers at the given splitpoint mid.

Returns an Error::OutOfBounds error if this split goes out of bounds of the buffer.