pub struct PtrBuffer { /* private fields */ }Expand description
A Buffer object backed by a pointer/size pair. Use this buffer type
when accessing unowned memory or arbitrary allocated memory.
Implementations
sourceimpl PtrBuffer
impl PtrBuffer
sourcepub fn new(pointer: *const u8, size: usize) -> Self
pub fn new(pointer: *const u8, size: usize) -> Self
Create a new buffer object with a given pointer and size. Just make sure the pointer outlives the object and not the other way around.
sourcepub fn set_pointer(&mut self, pointer: *const u8)
pub fn set_pointer(&mut self, pointer: *const u8)
Set the new pointer of this buffer.